==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_entities/warrantycoverage_001/CoverageByUsage.java <==

package net.datastream.schemas.mp_entities.warrantycoverage_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.UOMID_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTUSAGE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXPIRATIONUSAGE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USAGEUOMID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WARRANTYDURATIONUSAGE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}THRESHHOLDUSAGE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LASTVALUEUSAGE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "startusage",
    "expirationusage",
    "usageuomid",
    "warrantydurationusage",
    "threshholdusage",
    "lastvalueusage"
})
@XmlRootElement(name = "CoverageByUsage")
public class CoverageByUsage {

    @XmlElement(name = "STARTUSAGE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY startusage;
    @XmlElement(name = "EXPIRATIONUSAGE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY expirationusage;
    @XmlElement(name = "USAGEUOMID", namespace = "http://schemas.datastream.net/MP_fields")
    protected UOMID_Type usageuomid;
    @XmlElement(name = "WARRANTYDURATIONUSAGE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY warrantydurationusage;
    @XmlElement(name = "THRESHHOLDUSAGE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY threshholdusage;
    @XmlElement(name = "LASTVALUEUSAGE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY lastvalueusage;

    /**
     * Obtient la valeur de la propriété startusage.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getSTARTUSAGE() {
        return startusage;
    }

    /**
     * Définit la valeur de la propriété startusage.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setSTARTUSAGE(QUANTITY value) {
        this.startusage = value;
    }

    /**
     * Obtient la valeur de la propriété expirationusage.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getEXPIRATIONUSAGE() {
        return expirationusage;
    }

    /**
     * Définit la valeur de la propriété expirationusage.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setEXPIRATIONUSAGE(QUANTITY value) {
        this.expirationusage = value;
    }

    /**
     * Obtient la valeur de la propriété usageuomid.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUSAGEUOMID() {
        return usageuomid;
    }

    /**
     * Définit la valeur de la propriété usageuomid.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUSAGEUOMID(UOMID_Type value) {
        this.usageuomid = value;
    }

    /**
     * Obtient la valeur de la propriété warrantydurationusage.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getWARRANTYDURATIONUSAGE() {
        return warrantydurationusage;
    }

    /**
     * Définit la valeur de la propriété warrantydurationusage.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setWARRANTYDURATIONUSAGE(QUANTITY value) {
        this.warrantydurationusage = value;
    }

    /**
     * Obtient la valeur de la propriété threshholdusage.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTHRESHHOLDUSAGE() {
        return threshholdusage;
    }

    /**
     * Définit la valeur de la propriété threshholdusage.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTHRESHHOLDUSAGE(QUANTITY value) {
        this.threshholdusage = value;
    }

    /**
     * Obtient la valeur de la propriété lastvalueusage.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getLASTVALUEUSAGE() {
        return lastvalueusage;
    }

    /**
     * Définit la valeur de la propriété lastvalueusage.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setLASTVALUEUSAGE(QUANTITY value) {
        this.lastvalueusage = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/warrantycoverage_001/CoverageByUsage.java <==

package net.datastream.schemas.mp_entities.warrantycoverage_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.UOMID_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}STARTUSAGE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EXPIRATIONUSAGE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}USAGEUOMID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WARRANTYDURATIONUSAGE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}THRESHHOLDUSAGE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LASTVALUEUSAGE" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "startusage",
    "expirationusage",
    "usageuomid",
    "warrantydurationusage",
    "threshholdusage",
    "lastvalueusage"
})
@XmlRootElement(name = "CoverageByUsage")
public class CoverageByUsage {

    @XmlElement(name = "STARTUSAGE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY startusage;
    @XmlElement(name = "EXPIRATIONUSAGE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY expirationusage;
    @XmlElement(name = "USAGEUOMID", namespace = "http://schemas.datastream.net/MP_fields")
    protected UOMID_Type usageuomid;
    @XmlElement(name = "WARRANTYDURATIONUSAGE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY warrantydurationusage;
    @XmlElement(name = "THRESHHOLDUSAGE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY threshholdusage;
    @XmlElement(name = "LASTVALUEUSAGE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY lastvalueusage;

    /**
     * Gets the value of the startusage property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getSTARTUSAGE() {
        return startusage;
    }

    /**
     * Sets the value of the startusage property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setSTARTUSAGE(QUANTITY value) {
        this.startusage = value;
    }

    /**
     * Gets the value of the expirationusage property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getEXPIRATIONUSAGE() {
        return expirationusage;
    }

    /**
     * Sets the value of the expirationusage property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setEXPIRATIONUSAGE(QUANTITY value) {
        this.expirationusage = value;
    }

    /**
     * Gets the value of the usageuomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUSAGEUOMID() {
        return usageuomid;
    }

    /**
     * Sets the value of the usageuomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUSAGEUOMID(UOMID_Type value) {
        this.usageuomid = value;
    }

    /**
     * Gets the value of the warrantydurationusage property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getWARRANTYDURATIONUSAGE() {
        return warrantydurationusage;
    }

    /**
     * Sets the value of the warrantydurationusage property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setWARRANTYDURATIONUSAGE(QUANTITY value) {
        this.warrantydurationusage = value;
    }

    /**
     * Gets the value of the threshholdusage property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTHRESHHOLDUSAGE() {
        return threshholdusage;
    }

    /**
     * Sets the value of the threshholdusage property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTHRESHHOLDUSAGE(QUANTITY value) {
        this.threshholdusage = value;
    }

    /**
     * Gets the value of the lastvalueusage property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getLASTVALUEUSAGE() {
        return lastvalueusage;
    }

    /**
     * Sets the value of the lastvalueusage property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setLASTVALUEUSAGE(QUANTITY value) {
        this.lastvalueusage = value;
    }

}
